#ifndef H_CDW_ISO9660
#define H_CDW_ISO9660



long long cdw_iso_image_get_n_sectors(void);
double cdw_iso_image_get_size_mb(const char *fullpath);

enum {
	CDW_ISO9660_RR_NONE,
	CDW_ISO9660_RR_USEFUL,
	CDW_ISO9660_RR_FULL
};




#define CDW_ISO9660_ABST_LEN   37
#define CDW_ISO9660_COPY_LEN   37
#define CDW_ISO9660_PUBL_LEN  128
#define CDW_ISO9660_PREP_LEN  128
#define CDW_ISO9660_SYSI_LEN   32
#define CDW_ISO9660_VOLS_LEN  128
#define CDW_ISO9660_VOLI_LEN   32


#endif /* #ifndef H_CDW_ISO9660 */

